@@ -24,9 +24,9 @@ de.lorean.stylesheet <- function() {
 #'  markdown report file in the package.
 #'
 knit.report <- function(dl, report.name) {
-    knitr::knit2html(report.file(report.name),
-              envir=environment(),
-              stylesheet=de.lorean.stylesheet())
+  rmarkdown::render(report.file(report.name),
+                    envir=environment(),
+                    stylesheet=de.lorean.stylesheet())
 }
 
 
